# Typing Stubs for PyGObject

[![image](https://travis-ci.org/pygobject/pygobject-stubs.svg?branch=master)](https://travis-ci.org/pygobject/pygobject-stubs)
[![PyPI](https://img.shields.io/pypi/v/pygobject-stubs)](https://pypi.org/project/PyGObject-stubs)

## Installation
```
pip install PyGObject-stubs
```

## Generating stubs

Check the `tools` folder

Usage: `python generate.py -h`
